@@ -21,17 +21,17 @@ public:
 
     Response() = default;
 
-    Type type() const;
-    QByteArray action() const;
-    uint quantity() const;
-    QByteArray key() const;
-    QByteArray value() const;
-    QByteArray extra() const;
+    [[nodiscard]] Type type() const;
+    [[nodiscard]] QByteArray action() const;
+    [[nodiscard]] uint quantity() const;
+    [[nodiscard]] QByteArray key() const;
+    [[nodiscard]] QByteArray value() const;
+    [[nodiscard]] QByteArray extra() const;
 
     enum Result { Ok, No, Bye, Other };
 
-    Result operationResult() const;
-    bool operationSuccessful() const;
+    [[nodiscard]] Result operationResult() const;
+    [[nodiscard]] bool operationSuccessful() const;
 
     void clear();
     bool parseResponse(const QByteArray &line);
@@ -44,4 +44,3 @@ private:
     QByteArray m_extra;
 };
 }
-
