@@ -116,7 +116,7 @@ QString SieveActionDeleteHeader::code(QWidget *w) const
     const QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
     const QString valueStr = value->text();
 
-    return QStringLiteral("deleteheader %1 \"%2\" \"%3\";").arg((isNegative ? QLatin1String("not ") + matchTypeStr : matchTypeStr), headerStr, valueStr);
+    return QStringLiteral("deleteheader %1 \"%2\" \"%3\";").arg((isNegative ? QLatin1StringView("not ") + matchTypeStr : matchTypeStr), headerStr, valueStr);
 }
 
 QString SieveActionDeleteHeader::help() const
